@@ -46,10 +46,18 @@ function getRoute() {
     $('#route').css('color', 'red');
     try {
       console.log(route.replace(/ /g,''))
-      $('#'+route.replace(/ /g,'').replace(':','')).css('color', 'rgb(0, 208, 0)').css('font-weight', 'bold');
+      if (route == "4G LTE") {
+        $('#4GLTE'.replace(/ /g,'').replace(':','')).css('color', 'rgb(0, 208, 0)').css('font-weight', 'bold');
+        $('#Ethernet'.replace(/ /g,'').replace(':','')).css('color', 'rgb(0, 0, 0)').css('font-weight', 'normal');
+      }
+      if (route == "Ethernet") {
+        $('#Ethernet'.replace(/ /g,'').replace(':','')).css('color', 'rgb(0, 208, 0)').css('font-weight', 'bold');
+        $('#4GLTE'.replace(/ /g,'').replace(':','')).css('color', 'rgb(0, 0, 0)').css('font-weight', 'normal');                 
+      }
     } catch (e) {
       console.log(e)
     }
+    setTimeout(getRoute, 3000);
   })
 }
 
@@ -573,9 +581,9 @@ function showSpinner() {
       },
       success:function(response){
         document.getElementById("serversReachable").innerHTML = response.serversReachable + " of 3";
-        document.getElementById("networkLatency").innerHTML = " in " + response.rttavg + "ms";
+        document.getElementById("networkLatency").innerHTML = " in " + Math.round(response.rttavg) + " ms";
 
-        var packetslost = 100 - (response.packetsReceived / 12) * 100;
+        var packetslost = 100 - (response.packetsReceived / 3) * 100;
 
         document.getElementById("packetLoss").innerHTML = Math.round(packetslost * 100)/100 + "%";
         $('serversReachable').text(response.serversReachable);
@@ -587,8 +595,8 @@ function showSpinner() {
     });
   }
 
-  setTimeout(getPing, 10000)
-  setTimeout(getIpList, 5000)
+  setTimeout(getPing, 3000)
+  setTimeout(getIpList, 1500)
 //  setTimeout(getLanConnections, 2000)
 
 
